aboutsummaryrefslogtreecommitdiffstats
path: root/src/java/org/apache/fop/fo/flow/table/RowGroupBuilder.java
diff options
context:
space:
mode:
Diffstat (limited to 'src/java/org/apache/fop/fo/flow/table/RowGroupBuilder.java')
-rw-r--r--src/java/org/apache/fop/fo/flow/table/RowGroupBuilder.java8
1 files changed, 4 insertions, 4 deletions
diff --git a/src/java/org/apache/fop/fo/flow/table/RowGroupBuilder.java b/src/java/org/apache/fop/fo/flow/table/RowGroupBuilder.java
index c954be711..9748a77aa 100644
--- a/src/java/org/apache/fop/fo/flow/table/RowGroupBuilder.java
+++ b/src/java/org/apache/fop/fo/flow/table/RowGroupBuilder.java
@@ -57,7 +57,7 @@ abstract class RowGroupBuilder {
/**
* Receives notification of the end of the current row. If the current row finishes
* the row group, the {@link TableBody#addRowGroup(List)} method of the parent table
* part will be called.
*/
abstract void endTableRow();
@@ -65,21 +65,21 @@ abstract class RowGroupBuilder {
/**
* Receives notification of the end of the current row, when the source contains no
* fo:table-row element. If the current row finishes the row group, the
* {@link TableBody#addRowGroup(List)} method of the given table part will be called.
*
* <p>If the source does contain explicit fo:table-row elements, then the
* {@link #endTableRow()} method will be called instead.</p>
*
* @param part the part containing the current row
*/
- abstract void endRow(TableBody part);
+ abstract void endRow(TablePart part);
/**
* Receives notification of the start of a table-header/footer/body.
*
* @param part the part being started
*/
- abstract void startTablePart(TableBody part);
+ abstract void startTablePart(TablePart part);
/**
* Receives notification of the end of a table-header/footer/body. The current
@@ -57,7 +57,7 @@ abstract class RowGroupBuilder {
/**
* Receives notification of the end of the current row. If the current row finishes
- * the row group, the {@link TableBody#addRowGroup(List)} method of the parent table
+ * the row group, the {@link TablePart#addRowGroup(List)} method of the parent table
* part will be called.
*/
@@ -65,21 +65,21 @@ abstract class RowGroupBuilder {
* Receives notification of the end of the current row, when the source contains no
* fo:table-row element. If the current row finishes the row group, the
- * {@link TableBody#addRowGroup(List)} method of the given table part will be called.
+ * {@link TablePart#addRowGroup(List)} method of the given table part will be called.
*
* <p>If the source does contain explicit fo:table-row elements, then the